@@ -1,5 +1,5 @@
 package Getopt::EX::Colormap;
-use version; our $VERSION = version->declare("v1.25.0");
+use version; our $VERSION = version->declare("v1.25.1");
 
 use v5.14;
 use warnings;
@@ -24,7 +24,8 @@ use Getopt::EX::LabeledParam;
 use Getopt::EX::Util;
 use Getopt::EX::Func qw(callable);
 
-our $NO_COLOR    //= $ENV{NO_COLOR};
+our $NO_NO_COLOR //= $ENV{GETOPTEX_NO_NO_COLOR};
+our $NO_COLOR    //= !$NO_NO_COLOR && defined $ENV{NO_COLOR};
 our $RGB24       //= $ENV{COLORTERM}//'' eq 'truecolor' || $ENV{GETOPTEX_RGB24};
 our $LINEAR256   //= $ENV{GETOPTEX_LINEAR256};
 our $LINEAR_GREY //= $ENV{GETOPTEX_LINEARGREY};
@@ -1092,9 +1093,13 @@ variable C<$NO_RESET_EL> or C<GETOPTEX_NO_RESET_EL> environment.
 
 =head1 ENVIRONMENT
 
-If the environment variable C<NO_COLOR> is set, colorizing interface
-in this module never produce color sequence.  Primitive function such
-as C<ansi_code> is not the case.  See L<https://no-color.org/>.
+If the environment variable C<NO_COLOR> is set, regardless of its
+value, colorizing interface in this module never produce color
+sequence.  Primitive function such as C<ansi_code> is not the case.
+See L<https://no-color.org/>.
+
+If the module variable C<$NO_NO_COLOR> or C<GETOPTEX_NO_NO_COLOR>
+environment is true, C<NO_COLOR> value is ignored.
 
 B<color> method and B<colorize> function produces 256 or 24bit colors
 depending on the value of C<$RGB24> module variable.  Also 24bit mode
